==> Iuno-3.7.8.11768.tar.gz: Iuno-3.7.8.11768/Iuno/deploy/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: start_app.py 11244 2018-10-10 15:19:58Z Lavender $
#
# Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2018-10-11 00:19:58 +0900 (g|, 11 Q 2018) $
# $Revision: 11244 $

import os
import zipfile
import platform

from termcolor import colored, cprint
from django.conf import settings
from django.core.management.base import BaseCommand, CommandError
from django.core.management import call_command

from Iuno import DEVELOPMENT, STAGE, PRODUCTION
from Iuppiter.Util import classForName

from Iuppiter.Logging import createLogger

logger = createLogger(__name__)

class Command(BaseCommand):
    
    help = 'Scan all app Deploy.py and execute [name] function.'
    
    def add_arguments(self, parser):
        parser.add_argument('name', type=str, help="App name")

    def handle(self, *args, **options):
        name = options['name']

        # Unzip media
        # media Ƨb deploy | createA initial_data |ѤX
        media = hasattr(settings, 'IUNO_INITIAL_MEDIA')
        if media:
            media = settings.IUNO_INITIAL_MEDIA
            def extractMedia(media):
                zf = zipfile.ZipFile(media)
                zf.extractall('.')
                zf.close()
                
                sysStr = platform.system()
                if sysStr == "Linux":
                    os.system("convmv -f big5 -t utf8 -r --notest media")
                    
            if not os.path.isdir("media"):
                if os.path.isfile(media):
                    extractMedia(media)
            else:
                if not os.listdir("media"):
                    extractMedia(media)
                    
        # Iuno initialdata
        initialData = hasattr(settings, 'IUNO_INITIAL_DATA')
        
        if initialData:
            initialData = settings.IUNO_INITIAL_DATA
            if os.path.exists(initialData):
                call_command('loaddata', initialData)

        # get sites
        try:
            from django.contrib.sites.models import Site
            
            site = Site.objects.filter(id=settings.SITE_ID)[0]    
            siteNames = hasattr(settings, 'IUNO_SITE_DOMAIN_NAMES')
            if siteNames:
                siteNames = settings.IUNO_SITE_DOMAIN_NAMES
                if settings.SERVER_MODE == PRODUCTION:
                    site.domain = siteNames[PRODUCTION]
                elif settings.SERVER_MODE == STAGE:
                    site.domain = siteNames[STAGE]
                else:
                    site.domain = siteNames[DEVELOPMENT]
                site.save()
        except Exception as e:
            logger.error(str(e))

        # other
        for app in settings.INSTALLED_APPS:
            deploy = '%s.Deploy' % app
            
            try:
                deploy = classForName(deploy)
                if deploy:
                    func = getattr(deploy, name, None)
                    if func:
                        cprint(
                            "execute %s.Deploy.%s" % (app, name),
                            "blue",
                            "on_white",
                            attrs=["bold", "underline"],
                        )
                   
                        result = func()
            except Exception as e:
                continue
                
def attachSettings(settingsDict, iunoSiteDomainNames=None):
    """
    Attach default settings to settings.py.
    It must be called in settings by passing locals().

    @param settingsDict locals() in settings.py.
    @param allowedHosts if have IUNO_SITE_DOMAIN_NAMES
    """
    # Andy 
    # add ALLOWED_HOSTS by IUNO_SITE_DOMAIN_NAMES while in STAGE/PRODUCTION
    try:       
        siteNames = iunoSiteDomainNames
        
        
        siteName = siteNames[settingsDict['SERVER_MODE']].replace("www", "")
        if not siteName.startswith(".") and not siteName.startswith("127.0.0.1"):
            siteName = ".%s" % siteName
        settingsDict['ALLOWED_HOSTS'] += [
            siteName,
        ]
        
       
    except Exception as e:
        logger.error(str(e))        
    #######

==> Iuno-3.8.5.11789.tar.gz: Iuno-3.8.5.11789/Iuno/deploy/__init__.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: start_app.py 11244 2018-10-10 15:19:58Z Lavender $
#
# Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2018-10-11 00:19:58 +0900 (g|, 11 Q 2018) $
# $Revision: 11244 $

import os
import zipfile
import platform

from termcolor import colored, cprint
from django.conf import settings
from django.core.management.base import BaseCommand, CommandError
from django.core.management import call_command

from Iuno import DEVELOPMENT, STAGE, PRODUCTION
from Iuppiter.Util import classForName

from Iuppiter.Logging import createLogger

logger = createLogger(__name__)

class Command(BaseCommand):
    
    help = 'Scan all app Deploy.py and execute [name] function.'
    
    def add_arguments(self, parser):
        parser.add_argument('name', type=str, help="App name")

    def handle(self, *args, **options):
        name = options['name']

        # Unzip media
        # media Ƨb deploy | createA initial_data |ѤX
        media = hasattr(settings, 'IUNO_INITIAL_MEDIA')
        if media:
            media = settings.IUNO_INITIAL_MEDIA
            def extractMedia(media):
                zf = zipfile.ZipFile(media)
                zf.extractall('.')
                zf.close()
                
                sysStr = platform.system()
                if sysStr == "Linux":
                    os.system("convmv -f big5 -t utf8 -r --notest media")
                    
            if not os.path.isdir("media"):
                if os.path.isfile(media):
                    extractMedia(media)
            else:
                if not os.listdir("media"):
                    extractMedia(media)
                    
        # Iuno initialdata
        initialData = hasattr(settings, 'IUNO_INITIAL_DATA')
        
        if initialData:
            initialData = settings.IUNO_INITIAL_DATA
            if os.path.exists(initialData):
                call_command('loaddata', initialData)

        # get sites
        try:
            from django.contrib.sites.models import Site
            
            site = Site.objects.filter(id=settings.SITE_ID)[0]    
            siteNames = hasattr(settings, 'IUNO_SITE_DOMAIN_NAMES')
            if siteNames:
                siteNames = settings.IUNO_SITE_DOMAIN_NAMES
                if settings.SERVER_MODE == PRODUCTION:
                    site.domain = siteNames[PRODUCTION]
                elif settings.SERVER_MODE == STAGE:
                    site.domain = siteNames[STAGE]
                else:
                    site.domain = siteNames[DEVELOPMENT]
                site.save()
        except Exception as e:
            logger.error(str(e))

        # other
        for app in settings.INSTALLED_APPS:
            deploy = '%s.Deploy' % app
            
            try:
                deploy = classForName(deploy)
                if deploy:
                    func = getattr(deploy, name, None)
                    if func:
                        cprint(
                            "execute %s.Deploy.%s" % (app, name),
                            "blue",
                            "on_white",
                            attrs=["bold", "underline"],
                        )
                   
                        result = func()
            except Exception as e:
                continue
                
def attachSettings(settingsDict, iunoSiteDomainNames=None):
    """
    Attach default settings to settings.py.
    It must be called in settings by passing locals().

    @param settingsDict locals() in settings.py.
    @param allowedHosts if have IUNO_SITE_DOMAIN_NAMES
    """
    # add ALLOWED_HOSTS by IUNO_SITE_DOMAIN_NAMES while in STAGE/PRODUCTION
    try:       
        siteNames = iunoSiteDomainNames
        if settingsDict['SERVER_MODE'] != DEVELOPMENT:
            siteName = siteNames[settingsDict['SERVER_MODE']].replace("www", "")
            if not siteName.startswith(".") and not siteName.startswith(
                "127.0.0.1"):
                siteName = ".%s" % siteName
            settingsDict['ALLOWED_HOSTS'] += [
                siteName,
            ]
        return settingsDict['ALLOWED_HOSTS']
           
    except Exception as e:
        logger.error(str(e))
